Copying Assignments
===================

You may have multiple sections where you want to share assignments, or you may simply want to copy your assignments from the last time you taught a course to your current course.  You can do this.

.. figure:: Figures/copyAssignmentMenu.png
    :width: 800px
    :align: center
    :alt: Click the Copy Assignment tab
    :figclass: align-center
    
    Figure 1: Copying an assignment.
    

The copy assignment tab lets you select any of your old or current courses that use the same book.

.. figure:: Figures/selectCourseToCopy.png    
    :width: 800px
    :align: center
    :alt: Select the course to copy from
    :figclass: align-center
    
    Figure 2: Select the Course

Once the course is selected you can copy one or all of the assignments to your course.  If you do this multiple times courses with the same name will be ignored on the second copy.  This makes it a little easier if you just want to keep one course in sync with another so you don't have to remember and pick and choose.

.. figure:: Figures/selectCourseToCopy.png    
    :width: 800px
    :align: center
    :alt: Select one or all assignments to copy
    :figclass: align-center
    
    Figure 3: Select one or all assignments to copy.
    
    
The system will add the assignments to your current course and make its best guess to adjust the due date, based on the number of days from the beginning of each course.  This is going to get you in the ballpark but you will probably have to manually adjust it due to differences in the calendar from year to year.

    
